@@ -20,7 +20,7 @@ The base class for gui forms with actions.
 
 =cut
 
-use Mojo::Base 'CallBackery::GuiPlugin::Abstract';
+use Mojo::Base 'CallBackery::GuiPlugin::Abstract', -signatures;
 
 =head1 ATTRIBUTES
 
